@@ -1,11 +1,11 @@
 # coding: utf-8
 
-from django import forms
 from django.db.models import ForeignKey
 from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 
 from easy_select2.widgets import Select2Mixin, Select2, Select2Multiple
+from easy_select2 import forms as es2_forms
 
 
 # TODO: merge meta_fields and kwargs, which is the same.
@@ -39,14 +39,15 @@ def select2_modelform_meta(model,
     for field in model._meta.many_to_many:
         widgets.update({field.name: Select2Multiple(select2attrs=attrs)})
         # TODO: move this hackish bugfix to another mixin
-        msg = _('Hold down "Control", or "Command" on a Mac, to select more than one.')
+        msg = _('Hold down "Control", or "Command" on a Mac, '
+                'to select more than one.')
         field.help_text = field.help_text.replace(force_text(msg), '')
 
     meta_fields.update({
         'model': model,
         'widgets': widgets,
     })
-    if not 'exclude' in kwargs and not 'fields' in kwargs:
+    if 'exclude' not in kwargs and 'fields' not in kwargs:
         meta_fields.update({'exclude': []})
     meta_fields.update(**kwargs)
     meta = type('Meta', (object,), meta_fields)
@@ -58,7 +59,9 @@ def select2_modelform_meta(model,
 select2_meta_factory = select2_modelform_meta
 
 
-def select2_modelform(model, attrs=None, form_class=forms.ModelForm):
+# TODO: make FixedModelForm default form_class
+def select2_modelform(model, attrs=None,
+                      form_class=es2_forms.FixedModelForm):
     """
     Return ModelForm class for model with select2 widgets.
 
